#!/usr/bin/env python
# -*- coding: utf-8 -*-
import click
import boto3

from elasticsearch_loader import load
from elasticsearch_loader.parsers import json


def s3_iterator(bucket):
    for key in bucket.objects.all():
        yield json.load(key.get()['Body'])


@click.option('--prefix', default='', help='AWS_S3_PREFIX', envvar='ESL_S3_PREFIX')
@click.argument('bucket', type=str, nargs=1, required=True)
@click.pass_context
def _s3(ctx, prefix, bucket):
    s3 = boto3.resource('s3')
    bucket_obj = s3.Bucket(bucket)
    load(s3_iterator(bucket_obj), ctx.obj)


def register():
    return 's3', _s3



from setuptools import setup

try:
    import pypandoc
    long_description = pypandoc.convert('README.md', 'rst')
except Exception:
    long_description = ''

setup(
    name='esl-s3',
    author='Moshe Zada',
    version='0.2.22',
    py_modules=['esl_s3'],
    keywords=['elastic', 'elasticsearch', 'esl', 's3', 'bulk', 'loader', 'boto', 'aws', 'cloud'],
    url='https://github.com/moshe/elasticsearch_loader',
    license='',
    long_description=long_description,
    description='elasticsearch_loader plugin for AWS s3',
    install_requires=[
        'elasticsearch-loader',
        'boto3'
    ],
    tests_require=[
        'pytest'
    ],
    entry_points='''
        [esl.plugins]
        register=esl_s3:register
    '''
)
